︠7aed281c-8565-411d-9734-c7253529d338i︠
%html
<style>
em {
color: red
}
</style>
<center>
<h1>
Soliton Cellular Automata Using Rigged Configurations
</h1>
<h2>
Travis Scrimshaw
</h2>

This is <a href="https://arxiv.org/abs/1706.02443">joint work</a> with Xuan Liu (UMN).
</center>
︡0e7721fa-e7ce-455c-9bf6-fb4238b69ff7︡{"done":true,"html":"<style>\nem {\ncolor: red\n}\n</style>\n<center>\n<h1>\nSoliton Cellular Automata Using Rigged Configurations\n</h1>\n<h2>\nTravis Scrimshaw\n</h2>\n\nThis is <a href=\"https://arxiv.org/abs/1706.02443\">joint work</a> with Xuan Liu (UMN).\n</center>"}
︠a6f19e43-acd3-457b-886e-13b017b02e74is︠
%auto
from sage.combinat.crystals.letters import CrystalOfLetters
from sage.combinat.rigged_configurations.tensor_product_kr_tableaux import TensorProductOfKirillovReshetikhinTableaux
from sage.combinat.rigged_configurations.kr_tableaux import KirillovReshetikhinTableaux

class SolitonCellularAutomata(object):
    """
    A Soliton Cellular Automata system.

    INPUT:

    - ``initial_state`` -- the list of elements, can also be a string
      when ``vacuum`` is 1 and ``n`` is `sl_n`.
    - ``n`` -- (default: 2) the value `sl_n` or a Cartan type
    - ``vacuum`` -- (default: 1) the height of the vacuum element

    EXAMPLES::

        sage: B = SolitonCellularAutomata('341111112241111222311111112222344', 4)
        sage: B
        341111112241111222311111112222344

        sage: B = SolitonCellularAutomata([[4,1],[4,1],[2,1],[2,1],[2,1],[2,1],[3,1],[3,1],[3,2]], 4, 2)
        sage: B
        442222333
        111111112
    """
    def __init__(self, initial_state, n=2, vacuum=1):
        if n in ZZ:
            cartan_type = CartanType(['A',n-1,1])
        else:
            cartan_type = CartanType(n)
        if isinstance(initial_state, str):
            # We consider things 1-9
            initial_state = [[ZZ(x) if x != '.' else ZZ.one()] for x in initial_state]

        self._cartan_type = cartan_type
        self._vacuum = vacuum
        try:
            KRT = TensorProductOfKirillovReshetikhinTableaux(self._cartan_type,
                                                             [[vacuum,len(st)//vacuum]
                                                              for st in initial_state])
            self._states = [KRT(pathlist=initial_state)]
        except TypeError:
            KRT = TensorProductOfKirillovReshetikhinTableaux(self._cartan_type,
                                                             [[vacuum,1]
                                                              for st in initial_state])
            self._states = [KRT(*initial_state)]
        self._evolutions = []
        self._nballs = len(self._states[0])

    def evolve(self, carrier_capacity=None, carrier_index=None):
        """
        INPUT:

        - ``carrier_capacity`` -- (default: the number of balls in
          the system) the size of carrier
        """
        if carrier_capacity is None:
            carrier_capacity = self._nballs
        if carrier_index is None:
            carrier_index = self._vacuum
        passed = False
        empty_carrier = KirillovReshetikhinTableaux(self._cartan_type, carrier_index, carrier_capacity).module_generator()
        vacuum = KirillovReshetikhinTableaux(self._cartan_type, self._vacuum, 1).module_generator()
        carrier_factor = (carrier_index, carrier_capacity)
        last_final_carrier = empty_carrier
        state = self._states[-1]
        dims = state.parent().dims
        while not passed:
            KRT = TensorProductOfKirillovReshetikhinTableaux(self._cartan_type,
                                                             dims + (carrier_factor,))
            elt = KRT(*(list(state) + [empty_carrier]))
            RC = RiggedConfigurations(self._cartan_type, (carrier_factor,) + dims)
            elt2 = RC(*elt.to_rigged_configuration()).to_tensor_product_of_kirillov_reshetikhin_tableaux()
            # Back to an empty carrier or we are not getting any better
            if elt2[0] == empty_carrier or elt2[0] == last_final_carrier:
                passed = True
                KRT = TensorProductOfKirillovReshetikhinTableaux(self._cartan_type, dims)
                self._states.append(KRT(*elt2[1:]))
                self._evolutions.append(carrier_factor)
                if elt2[0] != empty_carrier:
                    print("Last carrier:")
                    print(ascii_art(last_final_carrier))
            else:
                # We need to add more vacuum states
                last_final_carrier = elt2[0]
                dims = tuple([(self._vacuum, 1)]*carrier_capacity) + dims

    # Output functions
    # ----------------

    def __repr__(self):
        return repr(sum((ascii_art('\n'.join(str(letter) for letter in b))
                        for b in self._states[-1]), ascii_art('')))

    def print_states(self, num=None, square=True):
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()

        vacuum = KirillovReshetikhinTableaux(self._cartan_type, self._vacuum, 1).module_generator()
        if square:
            num_factors = len(self._states[-1])
            for i,state in enumerate(self._states[:num]):
                state = [vacuum]*(num_factors - len(state)) + list(state)
                print("t: %s"%i)
                print( sum((ascii_art('\n'.join(str(letter) for letter in b)) if b != vacuum else ascii_art('.')
                            for b in state), ascii_art('')) )
        else:
            for i in range(num):
                print("t: %s"%i)
                print(sum((ascii_art('\n'.join(str(letter) for letter in b)) if b != vacuum else ascii_art('.')
                           for b in self._states[n]), ascii_art('')))

    def latex_states(self, num=None, square=True, box_width='5pt'):
        """
        Return a latex verion of the states.

        EXAMPLES::

            sage: B = SolitonCellularAutomata([[2],[-1],[1],[1],[1],[1],[1],[1],[1],[1],[1],[2],[2],[3],[-2],[1],[1],[1],[1],[1],[2],[-1],[1],[1],[1],[1],[1],[2],[3],[3],[-3],[-2]], ['C',3,1])
            sage: view(B.latex_states(15))

            sage: B = SolitonCellularAutomata([[2],[-2],[1],[1],[1],[1],[2],[0],[-3],[1],[1],[1],[1],[1],[2],[2],[3],[-3],], ['D',4,2])
            sage: view(B.latex_states(16))

        Example 4.13 from Yamada:

            sage: B = SolitonCellularAutomata([[3],[3],[1],[1],[1],[1],[2],[2],[2]], ['D',4,3])
            sage: view(B.latex_states(15))

        Example 4.14 from Yamada:

            sage: B = SolitonCellularAutomata([[3],[1],[1],[1],[2],[3],[1],[1],[1],[2],[3],[3]], ['D',4,3])
            sage: view(B.latex_states(15))
        """
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()
        from sage.misc.latex import latex
        from sage.misc.latex import LatexExpr

        vacuum = KirillovReshetikhinTableaux(self._cartan_type, self._vacuum, 1).module_generator()
        def compact_repr(b):
            if b == vacuum:
                return "\\makebox[%s]{.}"%box_width
            if self._vacuum == 1:
                return latex(list(b)[0])
            temp = "\\begin{array}{c}"
            temp += r"\\".join(latex(letter) for letter in reversed(b))
            temp += "\\end{array}"
            return "\\makebox[%s]{$%s$}"%(box_width, temp)

        ret = "{\\arraycolsep=0.5pt \\begin{array}"
        if square:
            num_factors = len(self._states[-1])
            ret += "{c|c%s}\n"%('c'*num_factors)
            for i,state in enumerate(self._states[:num]):
                state = [vacuum]*(num_factors - len(state)) + list(state)
                ret += "t = %s & \\cdots & %s \\\\\n"%(i, r" & ".join(compact_repr(b) for b in state))
        else:
            ret += "{cc}\n"
            for i in range(num):
                ret += "t = %s & \\cdots %s \\\\\n"%(i, r" \; ".join(compact_repr(b) for b in state))
        ret += "\\end{array}}\n"
        return LatexExpr(ret)

    def latex_states_word(self, num=None, square=True, box_width='6pt'):
        """
        Return a latex verion of the states.
        """
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()
        from sage.misc.latex import latex
        from sage.misc.latex import LatexExpr

        vacuum = KirillovReshetikhinTableaux(self._cartan_type, self._vacuum, 1).module_generator()
        def compact_repr(b):
            if b == vacuum:
                if self._vacuum == 1:
                    return "{\\color{gray} 1}"
                temp = "{\\color{gray} \\begin{aligned}"
                temp += r"\\".join(str(i) for i in range(1, self._vacuum+1))
                temp += "\\end{aligned}}"
                return temp
                #return "\\makebox[%s]{.}"%box_width
            if self._vacuum == 1:
                return latex(list(b)[0])
            temp = "\\begin{aligned}"
            temp += r"\\".join(latex(letter) for letter in reversed(b))
            temp += "\\end{aligned}"
            return temp
            #return "\\makebox[%s]{$%s$}"%(box_width, temp)

        ret = "\\begin{array}"
        if square:
            num_factors = len(self._states[-1])
            ret += "{c|c}\n"
            for i,state in enumerate(self._states[:num]):
                state = [vacuum]*(num_factors - len(state)) + list(state)
                ret += "t = %s & \\cdots %s \\\\\n"%(i, r" ".join(compact_repr(b) for b in state))
        else:
            ret += "{cc}\n"
            for i in range(num):
                ret += "t = %s & \\cdots %s \\\\\n"%(i, r" ".join(compact_repr(b) for b in state))
        ret += "\\end{array}\n"
        return LatexExpr(ret)

    def latex_tikz(self, num=None, vacuum_repr='.'):
        """
        Return a tikz latex version of the states.
        """
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()

        from sage.misc.latex import latex
        from sage.misc.latex import LatexExpr
        latex.add_package_to_preamble_if_available("tikz")
        latex.add_to_preamble("\usetikzlibrary{matrix}")
        res = "\\begin{tikzpicture}\n"
        vacuum = KirillovReshetikhinTableaux(self._cartan_type, self._vacuum, 1).module_generator()
        def compact_repr(b):
            if b == vacuum:
                return vacuum_repr
            if self._vacuum == 1:
                return latex(list(b)[0])
            return latex(b)

        num_factors = len(self._states[-1])
        #
        ret = "\\begin{tikzpicture}\n\\matrix [matrix of math nodes, column sep=-0.6em, nodes={minimum width=12pt}]{\n"
        for i,state in enumerate(self._states[:num]):
            ret += "t = {}\quad & \\cdots".format(i)
            state = [vacuum]*(num_factors - len(state)) + list(state)
            for b in state:
                ret += ' & {}'.format(compact_repr(b))
            ret += "\\\\\n"
        ret += "};\n\\end{tikzpicture}\n"
        return LatexExpr(ret)

def evolve_state(state, carrier, print_carrier=False):
    final = []
    try:
        u = [carrier.maximal_vector()]
    except (ValueError, TypeError, AttributeError):
        u = [carrier.module_generators[0]]
    # Assume every element has the same parent
    R = state[0].parent().R_matrix(carrier)
    for elt in reversed(state):
        up, eltp = R(R.domain()(elt, u[0]))
        u.insert(0, up)
        final.insert(0, eltp)
    def simple_repr(x):
        return ''.join(repr(x).strip('[]').split(', '))
    art = sum((ascii_art(
"""
{!s:^7}
   |
 --+-- {}
   |
{!s:^7}
""".format(simple_repr(state[i]), simple_repr(u[i+1]), simple_repr(final[i])))
             for i in range(len(state))), ascii_art(''))
    art._baseline = 2
    if print_carrier:
        print(ascii_art(simple_repr(u[0])) + art)
    return final

def evolve_state_latex(state, carrier):
    from sage.graphs.graph_latex import setup_latex_preamble
    setup_latex_preamble()
    final = []
    try:
        u = [carrier.maximal_vector()]
    except (ValueError, TypeError, AttributeError):
        u = [carrier.module_generators[0]]
    # Assume every element has the same parent
    R = state[0].parent().R_matrix(carrier)
    for elt in reversed(state):
        up, eltp = R(R.domain()(elt, u[0]))
        u.insert(0, up)
        final.insert(0, eltp)
    def simple_repr(x):
        return ''.join(repr(x).strip('[]').split(', '))
    ret = '\\begin{tikzpicture}[scale=0.75]\n'
    for i,val in enumerate(initial):
        ret += '\\node (i{}) at ({},0.9) {{${}$}};\n'.format(i, -2*i, simple_repr(val))
    for i,val in enumerate(final):
        ret += '\\node (t{}) at ({},-1) {{${}$}};\n'.format(i, -2*i, simple_repr(val))
    for i,val in enumerate(u):
        ret += '\\node (u{}) at ({},0) {{${}$}};\n'.format(i, -2*i+1, simple_repr(val))
    for i in range(len(initial)):
        ret += '\\draw[->] (i{}) -- (t{});\n'.format(i, i)
        ret += '\\draw[->] (u{}) -- (u{});\n'.format(i, i+1)
    ret += '\\end{tikzpicture}'
    return LatexExpr(ret)


################################################################################################

class DiscreteKdV(object):
    r"""
    The discrete KdV equation.

    INPUT:

    - ``delta`` -- the parameter `\delta`
    - ``vacuum`` -- the value of the vacuum
    - ``initial_state`` -- the initial state
    - ``prec`` -- the precison of the real numbers
    - ``epsilon`` -- the epsilon to determine when a number is sufficiently
      close to 0
    """
    def __init__(self, delta, vacuum, initial_state, prec=53, epsilon=0.01):
        if vacuum <= sqrt(delta):
            raise ValueError("invalid vacuum")
        R = RealField(prec)
        self._delta = R(delta)
        self._vacuum = R(vacuum)
        self._states = [[R(x) for x in initial_state]]
        self._epsilon = epsilon

    def __repr__(self):
        return "%s: "%len(self._states) + ' '.join(str(val) for val in self._states[-1])

    def evolve(self):
        v = self._vacuum
        delta = self._delta
        uinf = v - delta / v
        u = uinf
        state = self._states[-1]
        new_state = []
        i = 0

        while i < len(state) or abs(u - uinf) > self._epsilon:
            y = state[i] if i < len(state) else v
            new_state.append((u*y + delta) / y)
            u = u*y^2 / (u*y + delta)
            i += 1

        self._states.append(new_state)

    def print_states(self, num=None, square=True):
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()

        for i,st in enumerate(self._states):
            print("%s: "%i + ' '.join(str(val) for val in st))

    def plot_state(self, i, num_points=None, **kwds):
        while i >= len(self._states):
            self.evolve()
        state = self._states[i]
        if num_points is None:
            num_points = len(state)

        ymin = kwds.pop('ymin', min(min(state) for state in self._states))
        ymax = kwds.pop('ymax', max(max(state) for state in self._states))

        state = state + [self._vacuum]*(num_points - len(state))
        # Add a vacuum before and after for effect
        state = [self._vacuum] + state + [self._vacuum]
        return line(enumerate(state), ymin=ymin, ymax=ymax, **kwds)

    def plot_states(self, num=None, num_points=None, step=1, **kwds):
        if num is None:
            num = len(self._states)
        if num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()

        if num_points is None:
            num_points = len(self._states[-1])

        ymin = kwds.pop('ymin', min(min(state) for state in self._states))
        ymax = kwds.pop('ymax', max(max(state) for state in self._states))

        plots = []
        for state in self._states[:num:step]:
            state = state + [self._vacuum]*(num_points - len(state))
            # Add a vacuum before and after for effect
            state = [self._vacuum] + state + [self._vacuum]
            plots.append( line(enumerate(state), ymin=ymin, ymax=ymax, **kwds) )
        return animate(plots)

    def plot_center_mass(self, num=None):
        if num is None:
            num = len(self._states)
        elif num > len(self._states):
            for _ in range(num - len(self._states)):
                self.evolve()
        v = self._vacuum
        def center_mass(state):
            total = sum(val - v for val in state)
            return sum((val - v)*pos for pos,val in enumerate(state)) / total
        slope = (center_mass(self._states[10]) - center_mass(self._states[0])) / 10
        l = line([(0, center_mass(self._states[0])), (num, num*slope)], color='red')
        return line((i, center_mass(state))
                    for i,state in enumerate(self._states)) + l

    def animation(self, num=None, num_points=None, delay=20, **kwds):
        A = self.plot_states(num, num_points, **kwds)
        A.show(delay=delay)
︡35460504-f7cc-472a-ac57-e377684974b2︡{"done":true}︡
︠2b3a342c-1d97-4aa4-ab9d-b0e733980c26i︠
%html
<style>em {color: red}</style>
The classical <em>box-ball system</em> of Takahashi and Satsuma is a nonlinear discrete dynamical system where
<ul>
<li><em>states</em> are an empty box (vacuum) or a ball;</li>
<li><em>time evolution</em> is given by moving balls from right to left and putting them in the next available position.</li>
</ul>

Below, we represent vacuums by <font color=#666>\(1\)</font> and balls by \(2\).
︡6fb14e98-4243-49f3-9930-b0506e59922f︡{"done":true,"html":"<style>em {color: red}</style>\nThe classical <em>box-ball system</em> of Takahashi and Satsuma is a nonlinear discrete dynamical system where\n<ul>\n<li><em>states</em> are an empty box (vacuum) or a ball;</li>\n<li><em>time evolution</em> is given by moving balls from right to left and putting them in the next available position.</li>\n</ul>\n\nBelow, we represent vacuums by <font color=#666>\\(1\\)</font> and balls by \\(2\\)."}
︠0320e5c7-19c1-4aa4-8d16-b2b155e2be8c︠
BBS = SolitonCellularAutomata('1211221211222', ['A',1,1])
l = BBS.latex_states_word(5)
show(l)
︡02903092-e953-4aa0-9179-6441307e6003︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 2 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠039761c6-8346-47cc-b666-8852a9c1e2ae︠
BBS = SolitonCellularAutomata('112111221111122211112222', ['A',1,1])
l = BBS.latex_states_word(10)
show(l)
︡1edfa4a9-57e2-4a2e-96d7-f4ca120f787d︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠fbec260e-1e98-46fa-8029-e1e7fcfb9ae3︠
BBS = SolitonCellularAutomata('11111211111222112211111112222', ['A',1,1])
l = BBS.latex_states_word(15)
show(l)
︡36312a17-9fd6-4b3f-9c48-3fa324fe8bb2︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 10 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 11 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 12 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 13 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 14 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡{"done":true}︡
︠f2e16b9d-fb73-4f8b-8e53-4826ed4d9f0ai︠
%html
<style>em {color: red}</style>
The box-ball system has <em>solitonic</em> behavior:
<ul>
<li>Collections of adjacent balls, called <em>solitons</em>, move with speed according to their length/size.</li>
<li>After interaction, called <em>scattering</em>, the solitons retain their sizes.</li>
</ul>

This terminology comes from the fact that the box-ball system is an ultradiscrete version of the Kortewig-de Vries (KdV) nonlinear PDE. The KdV equation models water in a thin channel (which we can take as 1-dimensional) and has solutions of solitary waves called <it>solitons</it> that propograte proporitional to their speed and separate after interaction. Below, we give a discrete version of the KdV equation due to Hirota, but it still exhits the same behavior as the KdV equation solutions.
︡cc069cb7-aa11-4c2e-95f8-60e3524a7d6f︡{"done":true,"html":"<style>em {color: red}</style>\nThe box-ball system has <em>solitonic</em> behavior:\n<ul>\n<li>Collections of adjacent balls, called <em>solitons</em>, move with speed according to their length/size.</li>\n<li>After interaction, called <em>scattering</em>, the solitons retain their sizes.</li>\n</ul>\n\nThis terminology comes from the fact that the box-ball system is an ultradiscrete version of the Kortewig-de Vries (KdV) nonlinear PDE. The KdV equation models water in a thin channel (which we can take as 1-dimensional) and has solutions of solitary waves called <it>solitons</it> that propograte proporitional to their speed and separate after interaction. Below, we give a discrete version of the KdV equation due to Hirota, but it still exhits the same behavior as the KdV equation solutions."}
︠5cdff874-a736-428d-a483-0385da73ef98s︠
 D = DiscreteKdV(1, 5, [5,2,1,1,2,7,1,1,3,4] + [5]*40 + [5,5,5,2,2,2,3,4,5,5,5,5])
D.animation(500, step=5)
︡405a27ea-3f1d-4a3e-9b4f-1d05f80728ca︡{"file":{"filename":"/projects/681dd0ac-80e2-4cfd-a5ae-9c6bef57ebee/.sage/temp/compute0-us/32103/tmp__G_456.webm","show":true,"text":null,"url":"/681dd0ac-80e2-4cfd-a5ae-9c6bef57ebee/raw/.sage/temp/compute0-us/32103/tmp__G_456.webm"},"once":false}︡{"done":true}︡
︠dd78ef10-3bc0-4729-a313-e3a081136e58i︠
%html
We can generalize the box-ball system to multicolored balls, where we first do time evolution on the largest color first, then down to the smallest color. This still exhibits solitonic behavior, where the solitons are weakly increasing words from left to right.
︡60d96f92-1569-433e-9b70-efb5428ed71e︡{"done":true,"html":"We can generalize the box-ball system to multicolored balls, where we first do time evolution on the largest color first, then down to the smallest color. This still exhibits solitonic behavior, where the solitons are weakly increasing words from left to right."}
︠c82f4fe5-6d2d-4885-b499-f7c8fde9d138︠
BBS = SolitonCellularAutomata('114111251111124411112335', ['A',4,1])
l = BBS.latex_states_word(10)
show(l)
︡25eb22e6-2a99-4e47-9fc9-38c72f3686a2︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} 2 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} 2 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 2 5 {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 2 {\\color{gray} 1} 2 4 4 {\\color{gray} 1} 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} 2 4 {\\color{gray} 1} 4 {\\color{gray} 1} 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} 3 4 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} 3 5 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡{"done":true}︡
︠f90155c0-4684-4bf1-824b-f1509456cd0es︠
BBS = SolitonCellularAutomata('114111521111124411112335', ['A',4,1])
l = BBS.latex_states_word(10)
show(l)
︡607f8c37-bcd4-4027-b1e0-80b39ee956c9︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 2 {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} 2 2 5 4 {\\color{gray} 1} 4 {\\color{gray} 1} 2 3 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 2 5 {\\color{gray} 1} {\\color{gray} 1} 4 3 4 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 4 4 5 3 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} 5 {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots 2 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠c0d2077b-63d2-4b02-b0c0-82fed139240fi︠
%html
Notice that in the last example that $52$ is not a soliton as it travels with speed 1 and is separated upon scattering.
︡5d7573c6-33a4-4e24-a4cd-1f5879217b8c︡{"done":true,"html":"Notice that in the last example that $52$ is not a soliton as it travels with speed 1 and is separated upon scattering."}
︠269b6695-7e94-4c9a-9854-347bbb9847ads︠
BBS = SolitonCellularAutomata('1141113311221112451112344', ['A',4,1])
l = BBS.latex_states_word(14)
show(l)
︡305dcf71-1d75-42c8-9ad5-b0e0113aaa2b︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 4 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} 3 3 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} 2 3 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} 3 3 {\\color{gray} 1} 2 2 2 {\\color{gray} 1} {\\color{gray} 1} 4 5 {\\color{gray} 1} 2 3 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 3 3 2 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 5 3 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} 3 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 4 5 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 2 {\\color{gray} 1} {\\color{gray} 1} 4 4 5 {\\color{gray} 1} 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} 2 {\\color{gray} 1} 4 5 {\\color{gray} 1} {\\color{gray} 1} 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} 5 {\\color{gray} 1} {\\color{gray} 1} 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} 5 {\\color{gray} 1} 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 5 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 10 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 11 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 12 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 13 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠6d4f88a4-9198-44fb-8cf0-54d6839275e5i︠
%html
<style>em {color: red}</style>
<p>
We can generalize the box-ball system even further by using a certain class of crystals in affine type called <em>Kirillov&ndash;Reshetikhin (KR) crystals</em>. The idea comes from row-to-row transfer matrices of solvable lattice models. We represent elements of the box-ball system by the type $A_n^{(1)}$ (or $\widehat{\mathfrak{sl}}_{n+1}$) KR crystals $B^{1,1}$: the set $\{1, \dotsc, n+1\}$ with crystal operators
\[
f_i(b) = \begin{cases} b + 1 \mod{n+1} & \text{if } i = b \mod{n+1}, \\ 0 & \text{otherwise}, \end{cases}
\qquad
e_i(b) = \begin{cases} b - 1 \mod{n+1} & \text{if } i = b+1 \mod{n+1}, \\ 0 & \text{otherwise}. \end{cases}
\]
Note that the vacuum state corresponds to the element $1$.
</p>

<p>
We also need the KR crystal $B^{1,s}$, which are monomials in $B^{1,1}$ considered as commuting variables and the crystal operators act as above. Crystals also have a natural tensor product structure. Moreover, there is a unique crystal isomorphism
\[
R \colon B^{1,s} \otimes B^{1,s'} \to B^{1,s'} \otimes B^{1,s},
\]
called the <em>combinatorial $R$-matrix</em>, that is given by $b \otimes b' \mapsto \widetilde{b}' \otimes \widetilde{b}$ if and only if
\[
b \xleftarrow{\operatorname{RSK}} b' = \widetilde{b}' \xleftarrow{\operatorname{RSK}} \widetilde{b}.
\]
Last, we require the <em>local energy function</em>, $H \colon B^{1,s} \otimes B^{1,s'}$ defined as $H(b \otimes b')$ as the maximal number of boxes the  row $b'$ can cover of $b$.
</p>

<p>
For more background on type $A_n^{(1)}$ crystals, see <a href="http://www.aimath.org/WWN/kostka/crysdumb.pdf">Crystals for dummies</a> by Mark Shimozono.
</p>
︡b5432c55-96ba-44b8-8941-9a4e3cc256aa︡{"done":true,"html":"<style>em {color: red}</style>\n<p>\nWe can generalize the box-ball system even further by using a certain class of crystals in affine type called <em>Kirillov&ndash;Reshetikhin (KR) crystals</em>. The idea comes from row-to-row transfer matrices of solvable lattice models. We represent elements of the box-ball system by the type $A_n^{(1)}$ (or $\\widehat{\\mathfrak{sl}}_{n+1}$) KR crystals $B^{1,1}$: the set $\\{1, \\dotsc, n+1\\}$ with crystal operators\n\\[\nf_i(b) = \\begin{cases} b + 1 \\mod{n+1} & \\text{if } i = b \\mod{n+1}, \\\\ 0 & \\text{otherwise}, \\end{cases}\n\\qquad\ne_i(b) = \\begin{cases} b - 1 \\mod{n+1} & \\text{if } i = b+1 \\mod{n+1}, \\\\ 0 & \\text{otherwise}. \\end{cases}\n\\]\nNote that the vacuum state corresponds to the element $1$.\n</p>\n\n<p>\nWe also need the KR crystal $B^{1,s}$, which are monomials in $B^{1,1}$ considered as commuting variables and the crystal operators act as above. Crystals also have a natural tensor product structure. Moreover, there is a unique crystal isomorphism\n\\[\nR \\colon B^{1,s} \\otimes B^{1,s'} \\to B^{1,s'} \\otimes B^{1,s},\n\\]\ncalled the <em>combinatorial $R$-matrix</em>, that is given by $b \\otimes b' \\mapsto \\widetilde{b}' \\otimes \\widetilde{b}$ if and only if\n\\[\nb \\xleftarrow{\\operatorname{RSK}} b' = \\widetilde{b}' \\xleftarrow{\\operatorname{RSK}} \\widetilde{b}.\n\\]\nLast, we require the <em>local energy function</em>, $H \\colon B^{1,s} \\otimes B^{1,s'}$ defined as $H(b \\otimes b')$ as the maximal number of boxes the  row $b'$ can cover of $b$.\n</p>\n\n<p>\nFor more background on type $A_n^{(1)}$ crystals, see <a href=\"http://www.aimath.org/WWN/kostka/crysdumb.pdf\">Crystals for dummies</a> by Mark Shimozono.\n</p>"}
︠3b33ebd7-61c8-455b-b661-f061459ebb89s︠
K = crystals.KirillovReshetikhin(['A',3,1], 1, 2)
latex.eval(latex(K.digraph()))
︡8301f822-6788-4c36-a030-7ce6661c53f0︡{"file":{"filename":"/tmp/tmpnXCXh_.png","show":true,"text":null,"uuid":"24c94653-9bc1-4440-9701-e194101fdaec"},"once":false}︡{"stdout":"''"}︡{"stdout":"\n"}︡{"done":true}︡
︠936e753a-02a4-4070-b4d4-10a1340b3bcfs︠
Kp = crystals.KirillovReshetikhin(['A',3,1], 1, 3)
R = K.R_matrix(Kp)
H = K.local_energy_function(Kp)
for x in R.domain()[140:160]:
    ascii_art(x, '   |--->   ', R(x), '       H = ', H(x))
    print("")
︡4887a328-ce9d-4cee-8dd9-e00d491efa22︡{"stdout":"  2  4 #   1  1  1   |--->     1  2  4 #   1  1       H = 2"}︡{"stdout":"\n\n  2  4 #   1  1  2   |--->     1  2  4 #   1  2       H = 2\n\n  2  4 #   1  2  2   |--->     2  2  4 #   1  2       H = 2\n\n  2  4 #   2  2  2   |--->     2  2  4 #   2  2       H = 1\n\n  2  4 #   1  1  3   |--->     1  2  4 #   1  3       H = 2\n\n  2  4 #   1  2  3   |--->     2  2  4 #   1  3       H = 2\n\n  2  4 #   2  2  3   |--->     2  2  4 #   2  3       H = 1\n\n  2  4 #   1  3  3   |--->     2  3  4 #   1  3       H = 2\n\n  2  4 #   2  3  3   |--->     2  2  4 #   3  3       H = 1\n\n  2  4 #   3  3  3   |--->     2  3  4 #   3  3       H = 1\n\n  2  4 #   1  1  4   |--->     2  4  4 #   1  1       H = 2\n\n  2  4 #   1  2  4   |--->     2  4  4 #   1  2       H = 2\n\n  2  4 #   2  2  4   |--->     2  2  4 #   2  4       H = 1\n\n  2  4 #   1  3  4   |--->     2  4  4 #   1  3       H = 2\n\n  2  4 #   2  3  4   |--->     2  2  4 #   3  4       H = 1\n\n  2  4 #   3  3  4   |--->     2  3  4 #   3  4       H = 1\n\n  2  4 #   1  4  4   |--->     2  4  4 #   1  4       H = 1\n\n  2  4 #   2  4  4   |--->     2  4  4 #   2  4       H = 1\n\n  2  4 #   3  4  4   |--->     2  4  4 #   3  4       H = 1\n\n  2  4 #   4  4  4   |--->     2  4  4 #   4  4       H = 0\n\n"}︡{"done":true}︡
︠bcf7fbf3-afc3-4454-93ac-b2dc947a8a30i︠
%html
<style>em {color: red}</style>
Thus states of the box-ball system with $n$ colored balls become elements in an (semi) infinite tensor product of $B^{1,1}$ in type $A_n^{(1)}$ where only a finite number of factors are not equal to $1$. The time evolution is given by passing through a <em>carrier</em>, a factor $B^{1,s}$ with $s \gg 1$, using a series of combinatorial $R$-matrices with the initial element for the carrier being $1^s$.
︡9ba27848-7fd2-4968-8b13-0e62322f069a︡{"done":true,"html":"<style>em {color: red}</style>\nThus states of the box-ball system with $n$ colored balls become elements in an (semi) infinite tensor product of $B^{1,1}$ in type $A_n^{(1)}$ where only a finite number of factors are not equal to $1$. The time evolution is given by passing through a <em>carrier</em>, a factor $B^{1,s}$ with $s \\gg 1$, using a series of combinatorial $R$-matrices with the initial element for the carrier being $1^s$."}
︠26d892b0-839c-4716-a19b-6f8b5e71d66fs︠
v,a,b,c = list(crystals.KirillovReshetikhin(['A',3,1], 1,1))
carrier = crystals.KirillovReshetikhin(['A',3,1], 1, 5)
initial = [v,v,v,v,a,b,v,a,b,c]
latex.eval(evolve_state_latex(initial, carrier))
︡ca0e2b46-fb5f-4b00-bd1e-f637858b2e72︡{"file":{"filename":"/tmp/tmpgIwV4r.png","show":true,"text":null,"uuid":"409976bd-67fd-4a75-8c6d-70e6d5c37bbc"},"once":false}︡{"stdout":"''"}︡{"stdout":"\n"}︡{"done":true}︡
︠4f57f533-cdce-4f1b-a8d4-0bb31f4aa71bs︠
BBS = SolitonCellularAutomata('1111111313452451134411', ['A',4,1])
l = BBS.latex_states_word(2)
show(l)
︡13c9c97d-d347-4401-b252-80a076adb407︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 {\\color{gray} 1} 3 4 5 2 4 5 {\\color{gray} 1} {\\color{gray} 1} 3 4 4 {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 4 5 {\\color{gray} 1} 5 {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} 3 4 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠20789ee6-ad77-4d63-a5f2-63479aad54aes︠
v,a,b,c,d = list(crystals.KirillovReshetikhin(['A',4,1], 1,1))
carrier = crystals.KirillovReshetikhin(['A',4,1], 1, 5)
initial = [v,v,v,v,v,v,v,b,v,b,c,d,a,c,d,v,v,c,d,d,v,v]
next = evolve_state(initial, carrier, True)
︡fb4825ff-2357-4260-bffc-41388dcaba4f︡{"stdout":"                                                                             \n        1           1           1           1           1           1        \n        |           |           |           |           |           |        \n11111 --+-- 11111 --+-- 11111 --+-- 11111 --+-- 11113 --+-- 11133 --+-- 11334\n        |           |           |           |           |           |        \n        1           1           1           3           3           4        \n\n                                                                        \n   1           3           1           3           4           5        \n   |           |           |           |           |           |        \n --+-- 13345 --+-- 11345 --+-- 13455 --+-- 11455 --+-- 11255 --+-- 11245\n   |           |           |           |           |           |        \n   5           1           5           1           2           4        \n\n                                                                        \n   2           4           5           1           1           4        \n   |           |           |           |           |           |        \n --+-- 11145 --+-- 11115 --+-- 11114 --+-- 11145 --+-- 11455 --+-- 11155\n   |           |           |           |           |           |        \n   1           1           4           5           5           1        \n\n                                    \n   5           5           1           1   \n   |           |           |           |\n --+-- 11115 --+-- 11111 --+-- 11111 --+-- 11111\n   |           |           |           |\n   1           1           1           1   "}︡{"stdout":"\n"}︡{"done":true}︡
︠1f9ab091-981e-4924-8c43-a3d1f6e4db97s︠
''.join(repr(x).strip('[]') for x in initial)
''.join(repr(x).strip('[]') for x in next)
︡414c3d1c-15d2-4acb-841a-67624850b195︡{"stdout":"'1111111313452451145511'\n"}︡{"stdout":"'1113345151241145511111'\n"}︡{"done":true}︡
︠a138ebe8-892a-4819-a729-82ba237410ebi︠
%html
<style>em {color: red}</style>
Three more properties of box-ball systems we want to note are:
<ol>
<li>Solitons of length $s$ are parameterized by crystals $B^{1,s}$ of type $A_{n-1}^{(1)}$ given by subtracting 1 from each entry.</li>
<li>The scattering of two solitons corresponds to the combinatorial $R$-matrix of type $A_{n-1}^{(1)}$.</li>
<li>The <em>phase shift</em>, the difference of positions if there was no interaction, is equal to $2 \ell - H(x)$, where $\ell$ is the length of the smaller soliton.</li>
</ol>
︡ea4df99d-277e-4265-9b9d-4e3301bbf204︡{"done":true,"html":"<style>em {color: red}</style>\nThree more properties of box-ball systems we want to note are:\n<ol>\n<li>Solitons of length $s$ are parameterized by crystals $B^{1,s}$ of type $A_{n-1}^{(1)}$ given by subtracting 1 from each entry.</li>\n<li>The scattering of two solitons corresponds to the combinatorial $R$-matrix of type $A_{n-1}^{(1)}$.</li>\n<li>The <em>phase shift</em>, the difference of positions if there was no interaction, is equal to $2 \\ell - H(x)$, where $\\ell$ is the length of the smaller soliton.</li>\n</ol>"}
︠af096a30-f1dd-44ea-a6d6-9541bc866726s︠
SCA = SolitonCellularAutomata('111241111355', ['A',4,1])
l = SCA.latex_states_word(10)
show(l)
︡9e4b2d86-469b-406c-8bf3-c380977e51d6︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 5 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} {\\color{gray} 1} 3 5 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 {\\color{gray} 1} 3 5 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 5 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠1642e5e9-d6af-4c86-8790-39803a94d3cbs︠
K = crystals.KirillovReshetikhin(['A',3,1], 1, 2)
Kp = crystals.KirillovReshetikhin(['A',3,1], 1, 3)
R = K.R_matrix(Kp)
H = K.local_energy_function(Kp)
T = R.domain()
x = T(K(rows=[[1,3]]), Kp(rows=[[2,4,4]]))
ascii_art(x, '   |--->   ', R(x), '       H = ', H(x))
︡d48de991-fb1f-4106-b7e4-acbbefbc563d︡{"stdout":"  1  3 #   2  4  4   |--->     1  3  4 #   2  4       H = 1\n"}︡{"done":true}︡
︠94021347-fa2a-481d-a079-3353cf77c0aai︠
%html
<style>em {color: red}</style>
However, KR crystals $B^{r,s}$ (conjecturally) exists for all affine types, all nodes $r$ of the classical Dynkin diagram, and $s \in \ZZ_{>0}$. Moreover, there is a combinatorial $R$-matrix and vacuum states. We can use the same notation of states as being an (semi) infinite tensor product of $B^{r,1}$ and carriers $B^{r,s}$ for $s \gg 1$ with a series of combinatorial $R$-matrices being used to do time evolution. This appears to still exhibits solitonic behavior with the same properties as for the box-ball system. We call these dynamical systems <em>soliton cellular automata (SCA)</em>.
︡bf8c30f2-e501-4d9c-a60f-1e3c764d51e3︡{"done":true,"html":"<style>em {color: red}</style>\nHowever, KR crystals $B^{r,s}$ (conjecturally) exists for all affine types, all nodes $r$ of the classical Dynkin diagram, and $s \\in \\ZZ_{>0}$. Moreover, there is a combinatorial $R$-matrix and vacuum states. We can use the same notation of states as being an (semi) infinite tensor product of $B^{r,1}$ and carriers $B^{r,s}$ for $s \\gg 1$ with a series of combinatorial $R$-matrices being used to do time evolution. This appears to still exhibits solitonic behavior with the same properties as for the box-ball system. We call these dynamical systems <em>soliton cellular automata (SCA)</em>."}
︠45f7694e-8a68-429c-b6da-7b895ddba73bs︠
ascii_art([ct.dynkin_diagram() for ct in CartanType.samples(affine=True)])
︡941a14f0-d932-487c-9ebb-77c154813329︡{"stdout":"[                                                                 \n[                                                                 \n[        0                                                        \n[        O---------------+                O 0                     \n[        |               |                |                       \n[        |               |                |                       \n[ O<=>O  O---O---O---O---O     O<=>O  O---O---O---O=>=O     O<=>O \n[ 0   1  1   2   3   4   5     0   1  1   2   3   4   5     0   1 \n[ A1~  , A5~                 , B1~  , B5~                 , C1~  ,\n\n                                                          \n                                                          \n                           0                              \n                           O-------+       0 O   O 5      \n                           |       |         |   |        \n                           |       |         |   |        \n O=>=O---O---O---O=<=O     O---O---O     O---O---O---O    \n 0   1   2   3   4   5     3   1   2     1   2   3   4    \n C5~                     , D3~         , D5~             ,\n\n         O 0                                        \n         |                                          \n         |                                          \n         O 2                       O 2              \n         |                         |                \n         |                         |                \n O---O---O---O---O     O---O---O---O---O---O---O    \n 1   3   4   5   6     0   1   3   4   5   6   7    \n E6~                 , E7~                         ,\n\n                                                                      \n                                                                      \n                                                                      \n         O 2                                                          \n         |                                                            \n         |                         O---O---O=>=O---O       3          \n O---O---O---O---O---O---O---O     0   1   2   3   4     O=<=O---O    \n 1   3   4   5   6   7   8   0                           1   2   0    \n E8~                             , F4~                 , G2~         ,\n\n                                                          \n                                                          \n                                                          \n                                         O 0              \n                                         |                \n   4                                     |                \n O=<=O     O=<=O---O---O---O=<=O     O---O---O---O=<=O    \n 0   1     0   1   2   3   4   5     1   2   3   4   5    \n BC1~    , BC5~                    , B5~*                ,\n\n                                                                    \n                                                                    \n                                                                    \n                                                                    \n                                                                    \n                       O---O---O=<=O---O       3             4      \n O=<=O---O---O=>=O     0   1   2   3   4     O=>=O---O     O=>=O    \n 0   1   2   3   4                           1   2   0     0   1    \n C4~*                , F4~*                , G2~*        , BC1~*   ,\n\n                          ]\n                          ]\n                          ]\n                          ]\n                          ]\n                          ]\n O=>=O---O---O---O=>=O    ]\n 0   1   2   3   4   5    ]\n BC5~*                    ]"}︡{"stdout":"\n"}︡{"done":true}︡
︠02540745-3d6e-415c-83e5-ad4c42ba77a5s︠
SCA = SolitonCellularAutomata('111133111223', ['D',4,3])
l = SCA.latex_states_word(15)
show(l)
︡52c2eee8-7b4a-490d-bfa9-7c9cb2a6e6bf︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 {\\color{gray} 1} {\\color{gray} 1} 2 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 {\\color{gray} 1} 2 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 2 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{3} 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 10 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 11 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 0 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 12 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 3 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 13 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 3 {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 14 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 3 {\\color{gray} 1} {\\color{gray} 1} 2 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠4e5012fb-4bfd-4b8f-946e-b74d67957c74i︠
%html
The first question is how do we determine a soliton. We do this by finding tensor products such that the sum of all of the local energy equals $H(f_r v \otimes v)$, where $v$ is the vacuum element. However, the notion of length is a little more subtle.
︡11949b8c-e5ea-4144-9b78-8e4bfbae59fa︡{"done":true,"html":"The first question is how do we determine a soliton. We do this by finding tensor products such that the sum of all of the local energy equals $H(f_r v \\otimes v)$, where $v$ is the vacuum element. However, the notion of length is a little more subtle."}
︠e4e19d97-814a-49a0-8335-bb6e5b0e6fe7s︠
SCA = SolitonCellularAutomata([[1],[1],[2],[-3],[1],[1],[1],[3],[-1]], ['C',3,1])
show(SCA.latex_states_word(10))
︡a234c83b-ae38-45fb-8b64-5fb32d959ec4︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠821d235d-d2cb-4568-9463-6c1cacf9cc86s︠
SCA = SolitonCellularAutomata([[-2],['E'],[1],[1],[1],[1],[2],[3],[-2],[1],[1],[1],[1],[2],[2],[2],[-3]], ['A',6,2])
show(SCA.latex_states_word(10))
︡b1eff2e7-15a2-43e9-8237-79b01eb99eae︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 \\overline{3} \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset {\\color{gray} 1} 2 3 \\overline{2} {\\color{gray} 1} 2 2 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{2} \\emptyset 2 3 \\overline{2} 2 2 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{1} \\emptyset 3 \\overline{2} 2 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{1} \\emptyset {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{1} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{1} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{1} \\emptyset {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠1068a950-9aff-4c35-ac3d-70579becd3b9i︠
%html
<style>em {color: red}</style>
<p>
A <em>rigged configuration</em> is a sequence of partitions $\nu^{(r)}$, one for each node of the classical Dynkin diagram, with integers attached to row called <em>riggings</em>.
</p>
<p>
There is a (conjectural) bijection $\Phi$ between rigged configrations and tensor products of KR crystals. This bijection is recursively defined and very techincal (it comes from the Bethe ansatz of a related object in mathematical physics called Heisenberg spin chains), however, it <i><font color='blue'>linearizes</font></i> the dynamics of SCA. Thus, it allows us to extract information about SCA and the time evolution.
</p>
<hr>
<p>
<b>Theorem:</b> [Liu-S. 2017]
<br>
Assuming certain conjectures hold about the bijection $\Phi$, we show the following for certain classes of SCA:
<ol>
<li>Time evolution is described by changing the riggings on $\nu^{(r)}$ by adding their corresponding row length.</li>
<li>The lengths of the solitons corresponds to the rows of $\nu^{(r)}$.</li>
<li>Solitons of length $s$ are parameterized by crystals $B^{r',s}$ given by removing $r$ from the classical Dynkin diagram and $r'$ is the (set of) adjacent node(s).</li>
<li>The scattering of two solitons corresponds to the branched combinatorial $R$-matrix.</li>
<li>The phase shift is equal to $2 \ell + A_{rr'} H(x)$, where $\ell$ is the length of the smaller soliton and $A_{rr'}$ is the Cartan matrix.</li>
</ol>
</p>
︡5ff92831-27b8-4ffb-88af-a7baefb3f1d8︡{"done":true,"html":"<style>em {color: red}</style>\n<p>\nA <em>rigged configuration</em> is a sequence of partitions $\\nu^{(r)}$, one for each node of the classical Dynkin diagram, with integers attached to row called <em>riggings</em>.\n</p>\n<p>\nThere is a (conjectural) bijection $\\Phi$ between rigged configrations and tensor products of KR crystals. This bijection is recursively defined and very techincal (it comes from the Bethe ansatz of a related object in mathematical physics called Heisenberg spin chains), however, it <i><font color='blue'>linearizes</font></i> the dynamics of SCA. Thus, it allows us to extract information about SCA and the time evolution.\n</p>\n<hr>\n<p>\n<b>Theorem:</b> [Liu-S. 2017]\n<br>\nAssuming certain conjectures hold about the bijection $\\Phi$, we show the following for certain classes of SCA:\n<ol>\n<li>Time evolution is described by changing the riggings on $\\nu^{(r)}$ by adding their corresponding row length.</li>\n<li>The lengths of the solitons corresponds to the rows of $\\nu^{(r)}$.</li>\n<li>Solitons of length $s$ are parameterized by crystals $B^{r',s}$ given by removing $r$ from the classical Dynkin diagram and $r'$ is the (set of) adjacent node(s).</li>\n<li>The scattering of two solitons corresponds to the branched combinatorial $R$-matrix.</li>\n<li>The phase shift is equal to $2 \\ell + A_{rr'} H(x)$, where $\\ell$ is the length of the smaller soliton and $A_{rr'}$ is the Cartan matrix.</li>\n</ol>\n</p>"}
︠93767548-a64e-4902-9d58-b74eb5b92395s︠
SCA = SolitonCellularAutomata([[-4],[1],[1],[1],[4],[-3],[-2],[1],[1],[1],[1],[1],[3],[3],[-4],[-3],[1],[1],[1],[1],[1],[1],[2],[2],[2],[2],[3],[4]], ['D',4,1])
show(SCA.latex_states_word(10))
︡86348707-94e3-46ce-a3c7-14bc91cc77af︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{4} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 3 4 \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{4} {\\color{gray} 1} 4 \\overline{3} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{4} \\overline{3} 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 3 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{4} \\overline{3} \\overline{2} {\\color{gray} 1} 4 {\\color{gray} 1} 3 3 \\overline{4} \\overline{3} 2 2 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\overline{4} \\overline{3} \\overline{1} 2 3 3 4 \\overline{4} \\overline{3} 2 2 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\overline{4} \\overline{2} \\overline{1} 4 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} 2 2 \\overline{4} 3 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\overline{4} \\overline{2} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{3} {\\color{gray} 1} 2 2 3 \\overline{4} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\overline{4} \\overline{2} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 \\overline{3} {\\color{gray} 1} 2 3 \\overline{4} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\overline{4} \\overline{2} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{4} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 3 \\overline{4} \\overline{2} \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 4 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{4} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 4 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠7ae567c0-fd04-468e-a15c-a4b69c8cf4dcs︠
for st in SCA._states:
    print(' '.join(repr(x).strip('[]') for x in st))
    ascii_art(st.to_rigged_configuration())
    print("")
︡23ed2edb-55a5-4930-8b8e-9ad16ec94b02︡{"stdout":"-4 1 1 1 4 -3 -2 1 1 1 1 1 3 3 -4 -3 1 1 1 1 1 1 2 2 2 2 3 4\n11[ ][ ][ ][ ][ ][ ]-4   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n14[ ][ ][ ][ ]6          0[ ][ ][ ]0        0[ ]-1           0[ ]0\n17[ ][ ][ ]14           -1[ ][ ]-1                         \n24[ ]24                  0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 -4 1 4 -3 -2 1 1 1 1 3 3 -4 -3 1 1 1 1 2 2 2 2 3 4 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]2   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]10        0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]17          -1[ ][ ]-1                         \n52[ ]25                 0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 -4 -3 4 -2 1 1 1 3 3 -4 -3 1 1 2 2 2 2 3 4 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]8   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]14        0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]20          -1[ ][ ]-1                         \n52[ ]26                 0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 -4 -3 -2 1 4 1 3 3 -4 -3 2 2 2 2 3 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]14   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]18         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]23           -1[ ][ ]-1                         \n52[ ]27                  0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 -4 -3 -1 2 3 3 4 -4 -3 2 2 3 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]20   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]22         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]26           -1[ ][ ]-1                         \n52[ ]28                  0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 2 2 3 -4 -2 -1 4 -3 1 1 2 2 -4 3 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]26   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]26         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]29           -1[ ][ ]-1                         \n52[ ]29                  0[ ]0                             \n\n1 1 1 1 1 1 1 2 2 3 -4 -2 -2 1 1 2 4 -3 1 2 2 3 -4 1 1 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]32   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]30         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]32           -1[ ][ ]-1                         \n52[ ]30                  0[ ]0                             \n\n1 2 2 3 -4 -2 -2 1 1 1 1 2 2 4 -3 1 2 3 -4 1 1 1 1 1 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n39[ ][ ][ ][ ][ ][ ]38   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n42[ ][ ][ ][ ]34         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n45[ ][ ][ ]35           -1[ ][ ]-1                         \n52[ ]31                  0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 2 2 3 -4 -2 -2 1 1 1 1 1 1 2 2 4 -3 1 1 2 3 -4 1 1 1 1 1 1 1 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n67[ ][ ][ ][ ][ ][ ]44   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n70[ ][ ][ ][ ]38         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n73[ ][ ][ ]38           -1[ ][ ]-1                         \n80[ ]32                  0[ ]0                             \n\n1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 2 2 3 -4 -2 -2 1 1 1 1 1 1 1 1 2 2 4 -3 1 1 1 2 3 -4 1 1 1 1 1 1 1 1 1 4 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1\n67[ ][ ][ ][ ][ ][ ]50   1[ ][ ][ ][ ][ ]0  0[ ][ ][ ][ ]-1  0[ ][ ][ ][ ]0\n70[ ][ ][ ][ ]42         0[ ][ ][ ]0        0[ ]-1           0[ ]0\n73[ ][ ][ ]41           -1[ ][ ]-1                         \n80[ ]33                  0[ ]0                             \n\n"}︡{"done":true}︡
︠ceccaa6b-95d7-4cd2-a071-df90e6a24d1bi︠
%html
<style>p.padding {padding-left: 3cm;}</style>
<ol>
<li><b>Question:</b> Is this the correct definition of soltions and length?<p class="padding">We think so.</p></li>
<li><b>Open Problem:</b> The description of the phase shift is more subtle when the length is not the number of factors. Moreover, our statement about the phase shift likely does not generalize. Make this statement precise and true for the general case.</li>
</ol>
︡2ff08f47-538d-4575-9cf8-fdf0aa959c95︡{"done":true,"html":"<style>p.padding {padding-left: 3cm;}</style>\n<ol>\n<li><b>Question:</b> Is this the correct definition of soltions and length?<p class=\"padding\">We think so.</p></li>\n<li><b>Open Problem:</b> The description of the phase shift is more subtle when the length is not the number of factors. Moreover, our statement about the phase shift likely does not generalize. Make this statement precise and true for the general case.</li>\n</ol>"}
︠ad1bd1d6-3b73-4ab8-ab90-c8349ba0683ai︠
%html
Some more examples because they are fun to generate.
︡03a118c4-a039-4a2f-bd97-eb01bad1361f︡{"done":true,"html":"Some more examples because they are fun to generate."}
︠56e8a7d2-e365-439c-af8b-6b7cb77e03f3s︠
BBS = SolitonCellularAutomata([[2],[1],[1],[1],[1],[3],[0],[-2],[1],[1],[3],[-3],[1],[1],[1],[1],[1],[1],[2],[2],[2],[0],[-2]], ['B',4,1])
l = BBS.latex_states_word(13)
show(l)
︡0dbe8054-4971-48c6-802a-458c7da02255︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 0 \\overline{2} \\\\\nt = 1 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 3 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 2 2 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 2 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 \\overline{3} 2 2 2 0 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 3 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 {\\color{gray} 1} {\\color{gray} 1} \\overline{2} {\\color{gray} 1} 2 2 3 \\overline{3} \\overline{3} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 4 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 {\\color{gray} 1} {\\color{gray} 1} 2 3 \\overline{1} \\overline{3} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 5 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} {\\color{gray} 1} 2 4 \\overline{3} \\overline{2} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 6 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 7 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} {\\color{gray} 1} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 8 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 {\\color{gray} 1} 3 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 9 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 10 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 11 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\nt = 12 &amp; \\cdots {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 0 \\overline{4} \\overline{3} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 4 \\overline{2} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 2 3 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} 0 {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} {\\color{gray} 1} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠471ccfcd-8514-4d25-9956-c8deb07560f8s︠
BBS = SolitonCellularAutomata([[-1,2],[2,1],[2,1],[2,1],[2,1],[-2,2],[-1,2],[2,1],[2,1],[-2,1],[-2,1],[-2,2]], ['C',2,1], vacuum=2)
l = BBS.latex_states_word(11)
show(l)
︡e9c2e9d4-0658-401c-894a-a2d37d051cb0︡{"html":"<div align='center'>\\begin{array}{c|c}\nt = 0 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\\\\nt = 1 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 2 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 3 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 4 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 5 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 6 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}\\overline{2}\\\\\\overline{1}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 7 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 8 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 9 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\nt = 10 &amp; \\cdots {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} \\begin{aligned}2\\\\\\overline{1}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} \\begin{aligned}1\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\begin{aligned}2\\\\\\overline{2}\\end{aligned} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} {\\color{gray} \\begin{aligned}1\\\\2\\end{aligned}} \\\\\n\\end{array}\n</div>"}︡{"done":true}︡
︠b72b6c51-591e-4345-ba54-7d201b068c93︠









